Release notes
=============

Version 0.2
-----------

- Time out stuck requests
- Retry after more types of errors
- Permit encrypted public remotes
- Support showing public URLs in ``git annex whereis``
- Improve compatibility with git-annex < 5.20141219
- Properly accept implicit ``encryption=hybrid``

Version 0.1
-----------

- Initial release
